pub trait Realizes<R>where
R: Requirement,
Self: Realization,{ }Expand description
Represents the traceability of a realization to a requirement. This trait is implemented by the realizations that fulfill specific requirements.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.